@@ -11,7 +11,7 @@ from asynctest import TestCase as _TestCase
 from asynctest import _fail_on
 from asynctest.case import _Policy
 
-from tortoise import Tortoise
+from tortoise import Model, Tortoise
 from tortoise.backends.base.config_generator import generate_config as _generate_config
 from tortoise.exceptions import DBConnectionError
 from tortoise.transactions import current_transaction_map
@@ -283,6 +283,14 @@ class SimpleTestCase(_TestCase):  # type: ignore
             # clear the outcome, no more needed
             self._outcome = None
 
+    def assertListSortEqual(self, list1: List[Any], list2: List[Any], msg: Any = ...) -> None:
+        if isinstance(list1[0], Model):
+            super().assertListEqual(
+                sorted(list1, key=lambda x: x.pk), sorted(list2, key=lambda x: x.pk)
+            )
+        elif isinstance(list1[0], tuple):
+            super().assertListEqual(sorted(list1), sorted(list2))
+
     async def _run_outcome(self, outcome, expecting_failure: bool, testMethod: Callable) -> None:
         with outcome.testPartExecutor(self):
             await self._setUp()
