@@ -41,8 +41,10 @@ from tortoise.fields.relational import (
 )
 from tortoise.functions import Function
 from tortoise.query_utils import Prefetch, Q, QueryModifier, _get_joins_for_related_field
+from tortoise.router import router
 
 # Empty placeholder - Should never be edited.
+
 QUERY: QueryBuilder = QueryBuilder()
 
 if TYPE_CHECKING:  # pragma: nocoverage
@@ -88,6 +90,20 @@ class AwaitableQuery(Generic[MODEL]):
         self.capabilities: Capabilities = model._meta.db.capabilities
         self._annotations: Dict[str, Function] = {}
 
+    def _choose_db(self, for_write: bool = False) -> BaseDBAsyncClient:
+        """
+        Return the connection that will be used if this query is executed now.
+
+        :return: BaseDBAsyncClient:
+        """
+        if self._db:
+            return self._db
+        if for_write:
+            db = router.db_for_write(self.model)
+        else:
+            db = router.db_for_read(self.model)
+        return db or self.model._meta.db
+
     def resolve_filters(
         self,
         model: "Type[Model]",
@@ -255,6 +271,9 @@ class QuerySet(AwaitableQuery[MODEL]):
         "_custom_filters",
         "_group_bys",
         "_select_for_update",
+        "_select_for_update_nowait",
+        "_select_for_update_skip_locked",
+        "_select_for_update_of",
         "_select_related",
         "_select_related_idx",
     )
@@ -277,6 +296,9 @@ class QuerySet(AwaitableQuery[MODEL]):
         self._fields_for_select: Tuple[str, ...] = ()
         self._group_bys: Tuple[str, ...] = ()
         self._select_for_update: bool = False
+        self._select_for_update_nowait: bool = False
+        self._select_for_update_skip_locked: bool = False
+        self._select_for_update_of: Set[str] = set()
         self._select_related: Set[str] = set()
         self._select_related_idx: List[
             Tuple["Type[Model]", int, str, "Type[Model]"]
@@ -306,6 +328,9 @@ class QuerySet(AwaitableQuery[MODEL]):
         queryset._custom_filters = copy(self._custom_filters)
         queryset._group_bys = copy(self._group_bys)
         queryset._select_for_update = self._select_for_update
+        queryset._select_for_update_nowait = self._select_for_update_nowait
+        queryset._select_for_update_skip_locked = self._select_for_update_skip_locked
+        queryset._select_for_update_of = self._select_for_update_of
         queryset._select_related = self._select_related
         queryset._select_related_idx = self._select_related_idx
         return queryset
@@ -411,7 +436,9 @@ class QuerySet(AwaitableQuery[MODEL]):
         queryset._distinct = True
         return queryset
 
-    def select_for_update(self) -> "QuerySet[MODEL]":
+    def select_for_update(
+        self, nowait: bool = False, skip_locked: bool = False, of: Tuple[str, ...] = ()
+    ) -> "QuerySet[MODEL]":
         """
         Make QuerySet select for update.
 
@@ -421,6 +448,9 @@ class QuerySet(AwaitableQuery[MODEL]):
         if self.capabilities.support_for_update:
             queryset = self._clone()
             queryset._select_for_update = True
+            queryset._select_for_update_nowait = nowait
+            queryset._select_for_update_skip_locked = skip_locked
+            queryset._select_for_update_of = set(of)
             return queryset
         return self
 
@@ -699,7 +729,7 @@ class QuerySet(AwaitableQuery[MODEL]):
             **The output format may (and will) vary greatly depending on the database backend.**
         """
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db()  # type: ignore
         self._make_query()
         return await self._db.executor_class(model=self.model, db=self._db).execute_explain(
             self.query
@@ -777,7 +807,11 @@ class QuerySet(AwaitableQuery[MODEL]):
         if self._distinct:
             self.query._distinct = True
         if self._select_for_update:
-            self.query._for_update = True
+            self.query = self.query.for_update(
+                self._select_for_update_nowait,
+                self._select_for_update_skip_locked,
+                self._select_for_update_of,
+            )
         if self._select_related:
             for field in self._select_related:
                 field_split = field.split("__")
@@ -790,7 +824,7 @@ class QuerySet(AwaitableQuery[MODEL]):
 
     def __await__(self) -> Generator[Any, None, List[MODEL]]:
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db(self._select_for_update)  # type: ignore
         self._make_query()
         return self._execute().__await__()
 
@@ -876,7 +910,7 @@ class UpdateQuery(AwaitableQuery):
 
     def __await__(self) -> Generator[Any, None, int]:
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db(True)  # type: ignore
         self._make_query()
         return self._execute().__await__()
 
@@ -913,7 +947,7 @@ class DeleteQuery(AwaitableQuery):
 
     def __await__(self) -> Generator[Any, None, int]:
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db(True)  # type: ignore
         self._make_query()
         return self._execute().__await__()
 
@@ -951,7 +985,7 @@ class ExistsQuery(AwaitableQuery):
 
     def __await__(self) -> Generator[Any, None, bool]:
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db()  # type: ignore
         self._make_query()
         return self._execute().__await__()
 
@@ -993,7 +1027,7 @@ class CountQuery(AwaitableQuery):
 
     def __await__(self) -> Generator[Any, None, int]:
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db()  # type: ignore
         self._make_query()
         return self._execute().__await__()
 
@@ -1187,7 +1221,7 @@ class ValuesListQuery(FieldSelectQuery):
 
     def __await__(self) -> Generator[Any, None, List[Any]]:
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db()  # type: ignore
         self._make_query()
         return self._execute().__await__()  # pylint: disable=E1101
 
@@ -1273,7 +1307,7 @@ class ValuesQuery(FieldSelectQuery):
 
     def __await__(self) -> Generator[Any, None, List[dict]]:
         if self._db is None:
-            self._db = self.model._meta.db  # type: ignore
+            self._db = self._choose_db()  # type: ignore
         self._make_query()
         return self._execute().__await__()  # pylint: disable=E1101
 
